@@ -81,58 +81,41 @@ getBranchingVariable <- function(sol, alreadyBranched, primSupps) {
   branchVar
 }
 
-my.Rglpk_solve_LP <- function(obj, mat, dir, rhs, types = NULL, max = FALSE, bounds = NULL, verbose = FALSE) {
-  get.simpleTriplet <- sdcTable::get.simpleTriplet
-  if ( !identical(max, TRUE) && !identical(max, FALSE) ) {
+my.Rglpk_solve_LP <- function(obj, mat, dir, rhs, types=NULL, max=FALSE, 
+  bounds=NULL, verbose=FALSE, presolve=TRUE) {
+  if (!identical(max, TRUE) && !identical(max, FALSE)) {
     stop("'Argument 'max' must be either TRUE or FALSE!\n")
   }
-  direction_of_optimization <- as.integer(max)
-  if ( !identical(verbose, TRUE) && !identical(verbose, FALSE) ) {
+  if (!identical(verbose, TRUE) && !identical(verbose, FALSE)) {
     stop("'Argument 'verbose' must be either TRUE or FALSE.\n")
   }
-  if ( !class(mat) == "simpleTriplet" ) {
+  if (!class(mat)=="simpleTriplet") {
     stop("argument 'mat' must be of class 'simpleTriplet'\n")
   }
 
-  verb <- as.integer(verbose)
-  n_of_constraints <- length(dir)
-  direction_of_constraints <- match(dir, c("<", "<=", ">", ">=", "=="))
-  if ( any(is.na(direction_of_constraints)) ) {
-    stop("Argument 'dir' must be either '<', '<=', '>', '>=' or '=='.\n")
+  if (!all(dir %in% c("<", "<=", ">", ">=", "=="))) {
+    stop('directions must be one of "<", "<=", ">", ">= or "==".\n')
+  } 
+  
+  if (is.null(types)) {
+    types <- rep("C", length(obj))
   }
-  n_of_objective_vars <- length(obj)
-  if ( is.null(types) ) {
-    types <- "C"
-  }
-  if ( any(is.na(match(types, c("I", "B", "C"), nomatch = NA))) ) {
+  if (any(is.na(match(types, c("I", "B", "C"), nomatch = NA)))) {
     stop("'types' must be either 'B', 'C' or 'I'.\n")
   }
-  types <- rep(types, length.out = n_of_objective_vars)
   integers <- types == "I"
   binaries <- types == "B"
-  is_integer <- any(binaries | integers)
-  bounds <- as.glp_bounds(as.list(bounds), n_of_objective_vars)
-  x <- glp_call_interface(
-    obj,
-    n_of_objective_vars,
-    get.simpleTriplet(mat, type="rowInd", input=list()),
-    get.simpleTriplet(mat, type="colInd", input=list()),
-    get.simpleTriplet(mat, type="values", input=list()),
-    length(get.simpleTriplet(mat, type="values", input=list())),
-    rhs, direction_of_constraints, n_of_constraints, is_integer,
-    integers, binaries,
-    direction_of_optimization,
-    bounds[,1L],
-    bounds[,2L],
-    bounds[,3L],
-    verb
-  )
-  solution <- x$lp_objective_vars_values
-  solution[integers | binaries] <- round(solution[integers | binaries])
-  status <- as.integer(x$lp_status != 5L)
-  list(optimum = sum(solution * obj), solution = solution, status = status)
+  is_integer <- any(binaries | integers)  
+  
+  slammat <- simple_triplet_matrix(
+    i=mat@i, j=mat@j, v=mat@v, nrow=mat@nrRows, ncol=mat@nrCols)
+  x <- Rglpk_solve_LP(obj=obj, mat=slammat, dir=dir, rhs=rhs, 
+    bounds=bounds, types=types, max=max, 
+    control=list(verbose=verbose, presolve=presolve, tm_limit=0))    
+  status <- x$status
+  list(optimum=sum(x$solution * obj), solution=x$solution, status=status)
 }
-environment(my.Rglpk_solve_LP) <- environment(Rglpk_solve_LP)
+
 
 # calculates years, weeks, days, hours, minutes and seconds from integer number
 # secs: count of elapsed seconds (proc.time()[3])
